Bachelor 2015 Spoilers: How Far Does Whitney Bischoff Make It? | The Bachelor | Wetpaint
Description: Get used to hearing the name Whitney Bischoff, guys. Word on the street is that blondie locks is a serious contender for Chris Soules’ heart and that we’r...
Keywords: The Bachelor,Celebrity,Bachelor in Paradise,Features,Reality Gossip,Spoilers,TV Stars,The Bachelorette,The Bachelor Pad,The Bachelor,Chris Soules,Season 19,Bachelor 2015,Whitney Bischoff,Season 19 Hometown Dates,Season 19 Contestants
Date: 2014-12-18 01:01:00 UTC

Wetpaint

## The Bachelor

Spoiler!

# Bachelor 2015 Spoilers: How Far Does Whitney Bischoff Make It?

Share Tweet
Remind Me To Watch Reward Me

###### Credit: Reality Steve

Get used to hearing the name Whitney Bischoff, guys. Word on the street is that blondie locks is a serious contender for Chris Soules’ heart and that we’re going to see A LOT of her during The Bachelor 2015 season. Like, commit her face to memory now.
So how far does the registered nurse from Chicago (by way of Kentucky) make it? According to spoiler king Reality Steve, girlfriend’s bed of roses is quite comfy. In fact, her petals are still in full bloom. That’s right, boys and girls, Whit Bisch makes it all the way to Prince Farming’s heart place and is now wearing his Neil Lane diamond on her forever finger! Yep, she’s his one and only!

So how did Chris and Whitney sitting in a tree K-I-S-S-I-N-G turn into us imagining their babies? We first got whiff of their whirlwind romance when she got a 1-on-1 date in Des Moines, the final destination before Hometowns. Their romantic evening included a stroll along the Des Moines River Walk followed by dinner at a downtown hotspot. After picking the lobster from their teeth, the duo kissed awkwardly in front of a mural some production assistants who are rethinking their career choices painted of the couple.
Apparently the alley makeout sesh wasn’t as awkward as it seemed, because Chris gifted Whit a rose, for which she gifted him a trip to her favorite Chicago Italian restaurant, Quartino, during their Hometown Date. All must have gone swimmingly, because she then (presumably) has all her fantasies come true in the Fantasy Suite in Bali.
Prince Farming narrows it down to two, taking Whit and one other lucky lady back to… Iowa! Apparently he leads the two final gals to a barn where things go the way of Children of the Corn for the other gal but get all Field of Dreams happy for Whitney.
Chris proposes, Whitney says yee haw, and the two ride off on a tractor into the sunset together. Way to get it, girl!
Are you surprised Whitney is the last woman standing? Tell us below.
Source: Reality Steve

December 17, 2014 at 08:01PM EST by Rachel Evans

##### Related:

The Bachelor, Bachelor in Paradise, Celebrity, Chris Soules, Features, Reality Gossip, Spoilers, TV Stars, The Bachelor Pad, The Bachelorette,
- Season 19,
- Bachelor 2015,
- Whitney Bischoff,
- Season 19 Hometown Dates,
- Season 19 Contestants

More

#### Watch and Earn

More

#### Hot TV

- ##### Dancing With The Stars

- ##### Downton Abbey

- ##### Pretty Little Liars

- ##### Teen Mom

More

#### Popular

- ##### Pretty Little Liars Season 5B: 7 Questions We Want Answered

#### You Might Like

You've read of 5 maximum articles this month.
GET UNLIMITED ACCESS WHEN YOU UPGRADE TO VIP ›

###### Register now to become a Wetpaint VIP

Perks include access to all Wetpaint content, secret links to exclusive video, and best of all, points earnings and rewards from our partner, Viggle.

Tell me more or sign me up (just click below)
Connect with Facebook
CLOSE